@@ -2,18 +2,27 @@ from .ngram_counter import NgramCounter
 
 
 class NgramFrequency:
-    def __init__(self, nvalue=2, text="", joined=True):
+    def __init__(self, nvalue=2, text="", joined=True, alphabet="abcdefghijklmnopqrstuvwxyz", lower=True):
+        if lower:
+            self.text = text.lower()
+        else:
+            self.text = text
         self.text = text
         self.nvalue = int(nvalue)
         self.joined = joined
         self.frequency = {}
-        self.ngram_count = NgramCounter(nvalue=nvalue, text=text, joined=joined)
+        self.ngram_count = NgramCounter(nvalue=nvalue, text=text, joined=joined, alphabet=alphabet, lower=lower)
+        self.alphabet = alphabet
+        self.lower = lower
 
     def __repr__(self):
-        return 'NgramFrequency(nvalue={nvalue}, text={text}, joined={joined})'.format(
-            nvalue=self.nvalue,
-            text=self.text,
-            joined=self.joined
+        return 'NgramFrequency(nvalue={nvalue}, text={text}, joined={joined}, alphabet={alphabet}, lower={lower})'\
+            .format(
+                nvalue=self.nvalue,
+                text=self.text,
+                joined=self.joined,
+                alphabet=self.alphabet,
+                lower=self.lower
         )
 
     def __str__(self):
